package Acme::MetaSyntactic::python;
use strict;
use Acme::MetaSyntactic::List;
our @ISA = qw( Acme::MetaSyntactic::List );
our $VERSION = '1.000';
__PACKAGE__->init();
1;

=head1 NAME

Acme::MetaSyntactic::python - The Python theme

=head1 DESCRIPTION

The Pythonesque variable names used in Python examples.

=head1 CONTRIBUTOR

Ricardo Signes.

=head1 CHANGES

=over 4

=item *

2012-05-07 - v1.000

Received its own version number in Acme-MetaSyntactic-Themes version 1.000.

=item *

2005-03-28

Introduced in Acme-MetaSyntactic version 0.15.

=item *

2005-03-17

Submitted by Ricardo Signes.

=back

=head1 SEE ALSO

L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::List>.

=cut

__DATA__
# names
spam        eggs      ham         toast
beans       bacon     sausage     tomato
lobster     shallots  aubergine   truffle
pate        shrubbery herring     blancmange
